Translate Toolkit 2.2.3
***********************

*Released on 20 June 2017*

This release contains improvements and bug fixes.


Changes
=======

- Added `MinimalChecker` and `ReducedChecker` checkers.


Contributors
============

This release was made possible by the following people:

Rimas Kudelis, Leandro Regueiro.

And to all our bug finders and testers, a Very BIG Thank You.
